<?php

namespace Picea\Ui\Form;

use Picea\Extension\Extension;
use Picea\Extension\ExtensionTrait;
use Picea\Ui\Common\UiElement;
use Picea\Ui\Component\UiMessage;
use Picea\Ui\Component\UiPopup;

class Ui extends UiElement implements Extension {
    use ExtensionTrait;

    public string $token = "ui";

    protected /* ? mixed */ $value;

    protected string $name;

    public function parse(\Picea\Compiler\Context &$context, ?string $arguments, string $token) : string
    {
        $opt = $context->tokenOptions($token);

        switch(true) {
            case in_array('checkbox', $opt):
                $input = new UiCheckbox();
                break;

            case in_array('color', $opt):
                $input = new UiColor();
                break;

            case in_array('date', $opt):
                $input = new UiDate();
                break;

            case in_array('datetime', $opt):
                $input = new UiDatetime();
                break;

            case in_array('email', $opt):
                $input = new UiEmail();
                break;

            case in_array('file', $opt):
                $input = new UiFile();
                break;

            case in_array('form', $opt):
            case in_array('endform', $opt):
                $input = new UiForm();
                break;

            case in_array('hidden', $opt):
                $input = new UiHidden();
                break;

            case in_array('image', $opt):
                $input = new UiImage();
                break;

            case in_array('input', $opt):
                $input = new UiInput();
                break;

            case in_array('numeric', $opt):
                $input = new UiNumeric();
                break;

            case in_array('password', $opt):
                $input = new UiPassword();
                break;

            case in_array('radio', $opt):
                $input = new UiRadio();
                break;

            case in_array('range', $opt):
                $input = new UiRange();
                break;

            case in_array('search', $opt):
                $input = new UiSearch();
                break;

            case in_array('select', $opt):
                $input = new UiSelect();
                break;

            case in_array('tel', $opt):
                $input = new UiTel();
                break;

            case in_array('text', $opt):
                $input = new UiText();
                break;

            case in_array('textarea', $opt):
                $input = new UiTextarea();
                break;

            case in_array('time', $opt):
                $input = new UiText();
                break;

            case in_array('url', $opt):
                $input = new UiUrl();
                break;

            case in_array('week', $opt):
                $input = new UiWeek();
                break;

            case in_array('popup', $opt):
                $input = new UiPopup();
                break;

            case in_array('message', $opt):
                $input = new UiMessage();
                break;
        }

        if (empty($input)) {
            throw new \Exception("Missing token ? $token");
        }

        return $input->parse($context, $arguments, $token);
    }
}
